Introduction
============

This is collection of handy small tools for analyzing neural imaging  (esp. 
high resolution fMRI) data, which can be used both as a Python package and 
a set of command line tools. It is a useful augmentation to the AFNI tool chain.

Installation (in linux/mac)
===========================

Coming soon...

.. code-block:: shell

    $ pip install mripy
